
file_id = "SENSOR_ACQUISITION"

------------------
-- BEGIN SCRIPT --
------------------

log_msg("start..",file_id)

----------------------------------------------------------------------------
-- アラームデバイスの A/D 変換値と、DINPUT 値を読み込んで、
-- データベースに格納する。
-- 全ての SIGSENSOR, NETUIOデバイスを対象としてデータの取得を行う。
-- 取り込んだデータは、下記のキー名で DeviceServer のデータベースに格納する。
--
-- 詳細説明はアプリケーションノート (APNOTE05) を参照の事
--
-- キー名： ACQ-<DeviceName>-<Type>-<YYYYMMDDHHMM>
--
--      <DeviceName> 	デバイス名
--      <Type> 			DINPUT 値は、'DIN', A/D 変値は 'AD' が入る
--      <YYYYMMDDHHMM>  日付と時間を表したタイムスタンプ値。2001/1/31 10:20:30に
--						スクリプトを起動した場合は '200101311020' になる
-- 
-- 一つのデバイスに、DINPUT, A/D 変換機能の両方がある場合は、1 デバイスあたり、
-- <Type>が 'DIN', 'AD' を持った２つのデータが格納される。
----------------------------------------------------------------------------

local now = os.date "*t"
local timestamp = string.format("%4.4d%2.2d%2.2d%2.2d%2.2d",now["year"],now["month"],now["day"],now["hour"],now["min"])
local stat,buff1,bstat1,buff2,bstat2,buff3,bstat3,buff4,bstat4,din
local key_name,data_string

local stat,name,type,sysalert,neterr = alarm_all_list()
if not stat then error() end
for key,val in ipairs(name) do
	if ((type[key] == "SIGSENSOR") or (type[key] == "NETUIO")) and (not neterr[key]) then 

		---------------------------------------------
		-- A/D データ取得。デバイスの格納バッファにある
		-- 直近の平均値データを使用する
		---------------------------------------------
		stat,buff1,bstat1,buff2,bstat2,buff3,bstat3,buff4,bstat4 = alarm_adbuff_get(val)
		if not stat then error() end
		key_name = "ACQ-" .. val .. "-AD-" .. timestamp
		data_string = string.format("%d,%d,%d,%d",bstat1["MeanValue"],bstat2["MeanValue"],bstat3["MeanValue"],bstat4["MeanValue"])
		
		if not set_permanent_data(key_name,data_string) then error() end
		--if not set_oracle_data(key_name,data_string) then error() end
		log_msg("data stored: " .. key_name ..  " <- " .. data_string,file_id)

		---------------------------------------------
		-- DINPUT 取得
		---------------------------------------------
		stat,din = alarm_din_get(val)
		if not stat then error() end
		key_name = "ACQ-" .. val .. "-DIN-" .. timestamp
		data_string = string.format("%d",din)

		if not set_permanent_data(key_name,data_string) then error() end
		--if not set_oracle_data(key_name,data_string) then error() end
		log_msg("data stored: " .. key_name ..  " <- " .. data_string,file_id)

	end
end

------------------
-- END SCRIPT   --
------------------

